﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace howto_set_jpg_file_size
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // A temporary file name.
        private string TempFile;

        // The image loaded from the file.
        private Image OriginalImage = null;

        private void Form1_Load(object sender, EventArgs e)
        {
            cboCompressionLevel.Text = "75";
            TempFile = Application.StartupPath + @"\__temp.jpg";
        }

        // Open a file.
        private void mnuFileOpen_Click(object sender, EventArgs e)
        {
            if (ofdPicture.ShowDialog() == DialogResult.OK)
            {
                txtOriginalSize.Clear();
                txtActualLevel.Clear();
                txtActualSize.Clear();

                try
                {
                    // Load the file.
                    OriginalImage = ImageStuff.LoadBitmap(ofdPicture.FileName);
                    picImage.Image = OriginalImage;
                    mnuFileSaveAs.Enabled = true;
                    btnGo.Enabled = true;

                    // See how big the file is.
                    txtOriginalSize.Text = ImageStuff.GetFileSize(ofdPicture.FileName).ToFileSizeApi();
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Error loading file //" +
                        ofdPicture.FileName + "//\n" + ex.Message,
                        "Load Error", MessageBoxButtons.OK,
                        MessageBoxIcon.Error);
                }
            }
        }

        // Save the file with the selected compression level.
        private void mnuFileSaveAs_Click(object sender, EventArgs e)
        {
            if (OriginalImage == null) return;

            if (sfdPicture.ShowDialog() == DialogResult.OK)
            {
                try
                {
                    if (radSetCompressionLevel.Checked)
                    {
                        // Save at the indicated compression level.
                        int level = int.Parse(cboCompressionLevel.Text);
                        ImageStuff.SaveJpg(OriginalImage, sfdPicture.FileName, level);
                    }
                    else
                    {
                        // Save with the indicated maximum file size.
                        long max_size = 1024 * long.Parse(txtMaxFileSize.Text);
                        int level = ImageStuff.SaveJpgAtFileSize(OriginalImage, sfdPicture.FileName, max_size);
                    }
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Error saving file //" +
                        sfdPicture.FileName + "//\n" + ex.Message,
                        "Save Error", MessageBoxButtons.OK,
                        MessageBoxIcon.Error);
                }
            }
        }

        private void mnuFileExit_Click(object sender, EventArgs e)
        {
            Close();
        }

        // Compress the file.
        private void btnGo_Click(object sender, EventArgs e)
        {
            DateTime start_time = DateTime.Now;
            Cursor = Cursors.WaitCursor;

            if (radSetCompressionLevel.Checked)
            {
                // Save at the indicated compression level.
                int level = int.Parse(cboCompressionLevel.Text);
                ImageStuff.SaveJpg(OriginalImage, TempFile, level);
                txtActualLevel.Text = level.ToString();
            }
            else
            {
                // Save with the indicated maximum file size.
                long max_size = 1024 * long.Parse(txtMaxFileSize.Text);
                int level = ImageStuff.SaveJpgAtFileSize(OriginalImage, TempFile, max_size);
                txtActualLevel.Text = level.ToString();
            }

            // Display the actual size.
            txtActualSize.Text = ImageStuff.GetFileSize(TempFile).ToFileSizeApi();

            // Display the file.
            picImage.Image = ImageStuff.LoadBitmap(TempFile);

            Cursor = Cursors.Default;
            DateTime stop_time = DateTime.Now;
            TimeSpan elapsed = stop_time - start_time;
            Console.WriteLine("Level: " + txtActualLevel.Text +
                ", Size: " + txtActualSize.Text +
                ", Time: " + elapsed.TotalSeconds.ToString("0.00") + " sec");
        }

        // Select the Compression Level radio button.
        private void cboCompressionLevel_SelectedIndexChanged(object sender, EventArgs e)
        {
            radSetCompressionLevel.Checked = true;
        }

        // Select the Max File Size radio button.
        private void txtMaxFileSize_TextChanged(object sender, EventArgs e)
        {
            radSetMaxFileSize.Checked = true;
        }
    }
}
